@@ -30,7 +30,10 @@ _STR_MAP: dict[Head, Callable[[Expr, int], str]] = {
     Head.kw       : lambda e, i: f"{as_str(e.args[0])}={as_str(e.args[1])}",
     Head.assert_  : lambda e, i: " "*i + f"assert {as_str(e.args[0])}, {as_str(e.args[1])}".rstrip(", "),
     Head.comment  : lambda e, i: " "*i + f"# {e.args[0]}",
+    
+    Head.unop     : lambda e, i: " "*i + f"({as_str(e.args[0])}{as_str(e.args[1])})",
     Head.binop    : lambda e, i: " "*i + f"({as_str(e.args[1])} {as_str(e.args[0])} {as_str(e.args[2])})",
+    Head.aug      : lambda e, i: " "*i + f"{as_str(e.args[1])} {as_str(e.args[0])}= {as_str(e.args[2])}",
     
     Head.block    : lambda e, i: sjoin("\n", e.args, i),
     Head.function : lambda e, i: " "*i + f"def {as_str(e.args[0])}:\n{as_str(e.args[1], i+4)}",
@@ -40,6 +43,7 @@ _STR_MAP: dict[Head, Callable[[Expr, int], str]] = {
     Head.elif_    : lambda e, i: " "*i + f"if {rm_par(as_str(e.args[0]))}:\n{as_str(e.args[1], i+4)}\n" + \
                                  " "*i + f"else:\n{as_str(e.args[2], i+4)}",
     Head.for_     : lambda e, i: " "*i + f"for {rm_par(as_str(e.args[0]))}:\n{as_str(e.args[1], i+4)}",
+    Head.while_   : lambda e, i: " "*i + f"while {rm_par(as_str(e.args[0]))}:\n{as_str(e.args[1], i+4)}",
     Head.annotate : lambda e, i: f"{as_str(e.args[0], i)}: {as_str(e.args[1])}"
 }
 
