@@ -10,13 +10,16 @@ class Head(Enum):
     kw       = "kw"
     comment  = "comment"
     assert_  = "assert"
+    unop     = "unop"
     binop    = "binop"
+    aug      = "aug"
     block    = "block"
     function = "function"
     return_  = "return"
     if_      = "if"
     elif_    = "elif"
     for_     = "for"
+    while_   = "while"
     annotate = "annotate"
 
 EXEC = (Head.assign, Head.assert_, Head.comment, Head.block, Head.function, Head.return_,
