@@ -8,7 +8,7 @@ import inspect
 from typing import Callable, Iterable, Iterator, Any, TypedDict, Union, overload, TypeVar, NamedTuple
 from types import ModuleType
 
-from .ast import parse, Operator
+from .ast import parse
 from .expression import Head, Expr, symbol, EXEC
 from .symbol import Symbol
 
@@ -38,6 +38,12 @@ BINOP_MAP = {
     "__xor__": Symbol("^")
 }
 
+UNOP_MAP = {
+    "__pos__": Symbol("+"),
+    "__neg__": Symbol("-"),
+    "__invert__": Symbol("~"),
+}
+
 BUILTIN_MAP = {
     "__hash__": Symbol("hash"),
     "__len__": Symbol("len"),
@@ -92,6 +98,8 @@ class Macro(Expr, MutableSequence[Expr]):
         super().__init__(head=Head.block, args=args)
         self.active = True
         self._callbacks = []
+        if isinstance(flags, MacroFlags):
+            flags = flags._asdict()
         self._flags = MacroFlags(**flags)
         self._last_setval: Expr = None
     
@@ -189,7 +197,6 @@ class Macro(Expr, MutableSequence[Expr]):
             A function that will called after new expression is appended. Must take an expression
             or an expression with the last returned value as inputs.
         """        
-        # TODO: record called twice
         kwargs = dict(macro=self, 
                       returned_callback=returned_callback, 
                       record_returned=self._flags.Return
@@ -332,6 +339,20 @@ class Macro(Expr, MutableSequence[Expr]):
             self.append(expr)
             self._last_setval = None
         return out
+    
+    bound: dict[int, Macro] = {}
+    
+    def __get__(self, obj: Any, type=None):
+        if obj is None:
+            return self
+        obj_id = id(obj)
+        cls = self.__class__
+        try:
+            macro = cls.bound[obj_id]
+        except KeyError:
+            macro = cls(flags=self.flags)
+            cls.bound[obj_id] = macro
+        return macro
 
 class MacroMixin:
     """
@@ -508,6 +529,12 @@ class mFunction(mCallable):
                 expr = Expr(Head.del_, [target])
                 self._macro._last_setval = None
                 return expr
+        elif fname in UNOP_MAP.keys():
+            op = UNOP_MAP[fname]
+            def make_expr(obj: _O, *args):
+                expr = Expr(Head.unop, [op, self.to_namespace(obj)])
+                self._macro._last_setval = None
+                return expr
         elif fname in BINOP_MAP.keys():
             op = BINOP_MAP[fname]
             def make_expr(obj: _O, *args):
@@ -535,6 +562,12 @@ class mFunction(mCallable):
                 if expr is not None:
                     line = self.returned_callback(expr, out)
                 self._macro.append(line)
+                obj_id = id(obj)
+                if obj_id in self._macro.__class__.bound.keys():
+                    macro = self._macro.__class__.bound[obj_id]
+                    macro.append(line)
+                    # TODO: macro._last_setval should also be considered
+                    
             return out
 
         return method
@@ -595,6 +628,8 @@ class mProperty(mObject, property):
     obj: property
     def __init__(self, prop: property, macro: Macro, returned_callback: MetaCallable = None,
                  namespace: Symbol|Expr = None, flags: MacroFlagOptions = {}):
+        if isinstance(flags, MacroFlags):
+            flags = flags._asdict()
         self._flags = MacroFlags(**flags)
         super().__init__(prop, macro, returned_callback, namespace, record_returned=self._flags.Return)
         self.obj = self.getter(prop.fget)
@@ -611,6 +646,7 @@ class mProperty(mObject, property):
                 expr = Expr(Head.getattr, [self.to_namespace(obj), key])
                 expr = self.returned_callback(expr, out)
                 self._macro.append(expr)
+                self._record_instance(obj, expr)
                 self._macro._last_setval = None
             return out
         return self.obj.getter(getter)
@@ -633,6 +669,15 @@ class mProperty(mObject, property):
                 
                 line = self.returned_callback(expr, out)
                 self._macro.append(line)
+                
+                obj_id = id(obj)
+                if obj_id in self._macro.__class__.bound.keys():
+                    macro = self._macro.__class__.bound[obj_id]
+                    if macro._last_setval == target:
+                        macro.pop(-1)
+                    else:
+                        macro._last_setval = target
+                    macro.append(line)
                     
             return out
         
@@ -651,6 +696,7 @@ class mProperty(mObject, property):
                 expr = Expr(Head.del_, [target])
                 line = self.returned_callback(expr, out)
                 self._macro.append(line)
+                self._record_instance(obj, line)
                 self._macro._last_setval = None
             return out
         
@@ -667,6 +713,12 @@ class mProperty(mObject, property):
     
     def __delete__(self, obj) -> None:
         return self.obj.__delete__(obj)
+
+    def _record_instance(self, obj, line):
+        obj_id = id(obj)
+        if obj_id in self._macro.__class__.bound.keys():
+            macro = self._macro.__class__.bound[obj_id]
+            macro.append(line)
     
 class mModule(mObject):
     """
